OiRA

Help

1. Подготовка
2. Включване
3. Определяне + Оценяване
   1. 1 Commercial manned guarding
   2. Ω Добавени рискове (от Вас)
      1. Ω.1 The entrance floor is often wet
   - Без отговор
   - Отложено разглеждане
   - Правилно
   - Внимание
4. План за действие
5. Доклад
6. Статус 0%

Ако сте идентифицирали рискове, които не са включени в инструмента, можете да ги добавите на този етап:

Важно: С цел избягване на дублиране на рискове настоятелно препоръчваме да попълните всички предишни модули, ако не сте го направили досега.

Ако не трябва да добавяте рискове, продължете.

Назад Продължаване към плана за действие

Scroll to top
Back

## other-risks.html

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More